prac 1
Making a Raspberry Pi headless, and reaching it from the network using Wi-Fi/LAN and SSH 

prac 2
 Using sftp upload files from PC. 

prac 3
Write test motors.using tinker cad 

prac 4
Write a script to follow a predetermined path

prac 5
Develop Python code for testing the sensors
 
prac 6
Debug and test an array of led light (light strip) strip)

prac 7
Create an obstacle avoidance behavior for robot and test it. 

prac 8
8 Detect faces with Haar cascades. 
